# What is this ? 🧐

![File Image](https://upload.wikimedia.org/wikipedia/commons/thumb/2/20/Text-x-generic.svg/1024px-Text-x-generic.svg.png)

A library for make many operations for files Move Delete Name Filter ETC

## Instalation 

![Python Logo](https://1000logos.net/wp-content/uploads/2020/08/Python-Logo.png)

`pip install teo-files`

`py -m pip install teo-files`

## Contribute

1.- Make a fork

2.- Use the dev branch

3.- Write the changelog

4.- Make the pull request with the description

5.- Accepted the pull request and add New Release

## Credits

Made with :heart: in Ecuador by TeoDev1611

